@@ -380,7 +380,7 @@ class StreamSIOLoop(StreamBaseLoop):
         self.options = self._getDefaultOptions()
         self.extraStaticFiles = {}
         self.staticFiles = {}
-        self._enabled = True
+        self._enabled = not g.serviceSioDisable
         self.server = None
 
     def _getDefaultOptions(self):
@@ -519,7 +519,7 @@ class StreamSIOLoop(StreamBaseLoop):
 class StreamHTTPLoop(StreamBaseLoop):
     def __init__(self, stream):
         super().__init__(stream)
-        self._enabled = True
+        self._enabled = not g.serviceHttpDisable
         self.server = None
 
     @property
@@ -538,10 +538,10 @@ class StreamHTTPLoop(StreamBaseLoop):
         if env['REQUEST_METHOD'] == 'POST' and env['PATH_INFO'] == '/internal/trap':
             start_response('200 OK', [('Content-Type', 'text/json')])
             self.stream.close(code=98)
-            return [json.dumps({"message": "ok"}, ensure_ascii=False).encode('utf8')]
+            return [json.dumps({"success": "true"}, ensure_ascii=False).encode('utf8')]
 
         start_response('404 Not Found', [('Content-Type', 'text/json')])
-        return [b'{"message": "not found"}']
+        return [b'{"success": "false", "msg": "invalid request"}']
 
     def close(self):
         logger.debug("Stream HTTP Loop Closing...")
